﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Configuration;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Net.Http;
using System.Web;

namespace WindowsFormsApplication1
{

    public partial class Form1 : Form
    {
        public int pointNo;

        public Form1()
        {
            InitializeComponent();
        }


        private void Form1_Load(object sender, EventArgs e)
        {
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

        }


        private async void buttonExec_Click(object sender, EventArgs e)
        {
            // 結果をクリア
            textBoxStatus.Text = "";
            textBoxBody.Text = "";

            // URL実行
            try
            {
                HttpResponseMessage response = new HttpResponseMessage();

                using (HttpClient client = new HttpClient())
                {

                    TimeSpan timeout = new TimeSpan(0, 5, 0);      // Timeout 5分
                    client.Timeout = timeout;

                    // HeaderにX-ACT-Authorizationを設定
                    client.DefaultRequestHeaders.Add("X-ACT-Authorization", textBoxHeaders.Text);

                    if (comboBoxMethod.Text == "GET")
                    {
                        // GET
                        response = await client.GetAsync(textBoxURL.Text);
                    }

                    if (comboBoxMethod.Text == "POST")
                    {
                        // POST
                        // Headerにapplication/jsonを設定
                        HttpContent requestContent = new StringContent(textBoxRequestBody.Text, new UTF8Encoding(), "application/json");

                        response = await client.PostAsync(textBoxURL.Text, requestContent);
                    }

                }

                textBoxStatus.Text = response.StatusCode.ToString();
                textBoxBody.Text = await response.Content.ReadAsStringAsync();
            }
            catch (Exception ex)
            {
                textBoxStatus.Text = "NG";
                if (ex.InnerException != null)
                {
                    textBoxBody.Text = ex.Message.ToString() + Environment.NewLine + ex.InnerException.ToString();
                }
                else
                {
                    textBoxBody.Text = ex.Message.ToString();
                }
            }

        }

        private void buttonReset_Click(object sender, EventArgs e)
        {
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

        }


        // オプション項目

        private void buttonCreate_Click(object sender, EventArgs e)
        {
            int i;

            // App.configからURLを取得
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

            // 必須パラメータ
            if (textBoxUserName.Text.Length == 0)
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            if (textBoxPassword.Text.Length == 0)
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            // UserNameとPasswordからヘッダー作成
            // 「ユーザー名:パスワード」をBASE64エンコードしたものを値として表示
            string base64str = textBoxUserName.Text + ":" + textBoxPassword.Text;
            byte[] bs = System.Text.Encoding.UTF8.GetBytes(base64str);
            textBoxHeaders.Text = Convert.ToBase64String(bs);

            // GETの場合、URLに付与
            if (comboBoxMethod.Text == "GET")
            {
                if (textBoxAddress.Text.Length > 0)
                {
                    // カンマで区切る
                    string[] stArrayData = textBoxAddress.Text.Split(',');

                    // 初期化
                    pointNo = 1;
                    foreach (string stData in stArrayData)
                    {
                        textBoxURL.Text += "?" + comboBoxAddress1.Text + pointNo.ToString() + "=" + stData;
                        pointNo++;
                    }

                }
                else
                {
                    MessageBox.Show("必須パラメータの入力がありません。");
                    return;
                }

                // オプション
                // 測地系
                if (radioButtonDatum0.Checked != false)
                {
                    textBoxURL.Text += "&Datum=0";
                }
                else
                {
                    textBoxURL.Text += "&Datum=1";
                }
                // 郵便番号時、複数の住所候補が見つかった場合の選択方法
                if (radioButtonZipSelect0.Checked != false)
                {
                    textBoxURL.Text += "&ZipSelect=0";
                }
                else if (radioButtonZipSelect1.Checked != false)
                {
                    textBoxURL.Text += "&ZipSelect=1";
                }
                else
                {
                    textBoxURL.Text += "&ZipSelect=2";
                }

            }

            // POSTの場合、RequestBody作成
            if (comboBoxMethod.Text == "POST")
            {
                if (textBoxAddress.Text.Length > 0)
                {

                    textBoxRequestBody.Text = "{";

                    // items
                    textBoxRequestBody.Text += "\"items\" : [";

                    string[] stArrayData = textBoxAddress.Text.Split(',');
                    for (i = 0; i < stArrayData.Length; i++)
                    {
                        textBoxRequestBody.Text += "\"" + stArrayData[i].ToString() + "\"";
                        if (i + 1 < stArrayData.Length)
                        {
                            textBoxRequestBody.Text += ",";
                        }
                    }
                    textBoxRequestBody.Text += "]";

                    textBoxRequestBody.Text += "}";
                }
                else
                {
                    MessageBox.Show("必須パラメータの入力がありません。");
                    return;
                }

                // オプション
                // 測地系
                if (radioButtonDatum0.Checked != false)
                {
                    textBoxURL.Text += "?Datum=0";
                }
                else
                {
                    textBoxURL.Text += "?Datum=1";
                }
                // 郵便番号時、複数の住所候補が見つかった場合の選択方法
                if (radioButtonZipSelect0.Checked != false)
                {
                    textBoxURL.Text += "&ZipSelect=0";
                }
                else if (radioButtonZipSelect1.Checked != false)
                {
                    textBoxURL.Text += "&ZipSelect=1";
                }
                else
                {
                    textBoxURL.Text += "&ZipSelect=2";
                }


            }


        }


        private void linkLabelACT_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.act-inc.co.jp");
        }

        private void linkLabelNWID_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.act-inc.jp/dl/doc/NWIDrule.pdf");
        }


    }
}
